@@ -15,8 +15,9 @@
 #'
 #' @references Ogle, D.H. 2016. \href{https://fishr-core-team.github.io/fishR/pages/books.html#introductory-fisheries-analyses-with-r}{Introductory Fisheries Analyses with R}. Chapman & Hall/CRC, Boca Raton, FL.
 #' 
-#' @docType package
-#' 
 #' @name FSA
 #' 
+#' @keywords internal
+"_PACKAGE"
+
 NULL
\ No newline at end of file
