@@ -2,43 +2,44 @@
 #'
 #' @description Convenience function for calculating (traditional) PSD-X and (incremental) PSD X-Y values for all Gabelhouse lengths and increments thereof.
 #'
-#' @details Computes the (traditional) PSD-X and (incremental) PSD X-Y values, with associated confidence intervals, for each Gabelhouse lengthAll PSD-X and PSD X-Y values are printed if \code{what="all"} (DEFAULT), only PSD-X values are printed if \code{what="traditional"}, only PSD X-Y values are printed if \code{what="incremental"}, and nothing is printed (but the matrix is still returned) if \code{what="none"}.
+#' @details Computes the (traditional) PSD-X and (incremental) PSD X-Y values, with associated confidence intervals, for each Gabelhouse length. All PSD-X and PSD X-Y values are printed if \code{what="all"} (DEFAULT), only PSD-X values are printed if \code{what="traditional"}, only PSD X-Y values are printed if \code{what="incremental"}, and nothing is printed (but the matrix is still returned) if \code{what="none"}.
 #' 
 #' Confidence intervals can be computed with either the multinomial (Default) or binomial distribution as set in \code{method}See details in \code{\link{psdCI}} for more information.
+#' This function may be used for species for which Gabelhouse length categories are not defined. In this case do not include a name in \code{species}, but define at least two lengths in \code{addLens} where the first category MUST be called \dQuote{stock}.
 #'
-#' @param formula A formula of the form \code{~length} where \dQuote{length} generically represents a variable in \code{data} that contains the observed lengthsNote that this formula may only contain one variable and it must be numeric.
+#' @param formula A formula of the form \code{~length} where \dQuote{length} generically represents a variable in \code{data} that contains the observed lengths. Note that this formula may only contain one variable and it must be numeric.
 #' @param data A data.frame that minimally contains the observed lengths given in the variable in \code{formula}.
-#' @param species A string that contains the species name for which Gabelhouse lengths existSee \code{\link{psdVal}} for details.
-#' @param units A string that indicates the type of units used for the lengthsChoices are \code{mm} for millimeters (DEFAULT), \code{cm} for centimeters, and \code{in} for inches.
-#' @param what A string that indicates the type of PSD values that will be printedSee details.
+#' @param species A string that contains the species name for which Gabelhouse lengths exist. See \code{\link{psdVal}} for details. See details for how to use this function for species for which Gabelhouse lengths are not defined.
+#' @param units A string that indicates the type of units used for the lengths. Choices are \code{mm} for millimeters (DEFAULT), \code{cm} for centimeters, and \code{in} for inches.
+#' @param what A string that indicates the type of PSD values that will be printed. See details.
 #' @param drop0Est A logical that indicates whether the PSD values that are zero should be dropped from the output.
-#' @param method A character that identifies the confidence interval method to useSee details in \code{\link{psdCI}}.
-#' @param addLens A numeric vector that contains minimum lengths for additional categoriesSee \code{\link{psdVal}} for details.
-#' @param addNames A string vector that contains names for the additional lengths added with \code{addLens}See \code{\link{psdVal}} for details.
+#' @param method A character that identifies the confidence interval method to use. See details in \code{\link{psdCI}}.
+#' @param addLens A numeric vector that contains minimum lengths for additional categories. See \code{\link{psdVal}} for details.
+#' @param addNames A string vector that contains names for the additional lengths added with \code{addLens}. See \code{\link{psdVal}} for details.
 #' @param justAdds A logical that indicates whether just the values related to the length sin \code{addLens} should be returned.
 #' @param conf.level A number that indicates the level of confidence to use for constructing confidence intervals (default is \code{0.95}).
-#' @param showIntermediate A logical that indicates whether the number of fish in the category and the number of stock fish (i.e., \dQuote{intermediate} values) should be included in the returned matrixDefault is to not include these values.
-#' @param digits A numeric that indicates the number of decimals to round the result toDefault is zero digits following the recommendation of Neumann and Allen (2007).
+#' @param showIntermediate A logical that indicates whether the number of fish in the category and the number of stock fish (i.e., \dQuote{intermediate} values) should be included in the returned matrix. Default is to not include these values.
+#' @param digits A numeric that indicates the number of decimals to round the result to. Default is zero digits following the recommendation of Neumann and Allen (2007).
 #'
-#' @return A matrix with columns that contain the computed PSD-X or PSD X-Y values and associated confidence intervalsIf \code{showIntermediate=TRUE} then the number of fish in the category and the number of stock fish will also be shown.
+#' @return A matrix with columns that contain the computed PSD-X or PSD X-Y values and associated confidence intervals. If \code{showIntermediate=TRUE} then the number of fish in the category and the number of stock fish will also be shown.
 #' 
 #' @section Testing: Point estimate calculations match those constructed "by hand."
 #'
-#' @author Derek H. Ogle, \email{derek@@derekogle.com}
+#' @author Derek H. Ogle, \email{DerekOgle51@gmail.com}
 #'
 #' @section IFAR Chapter: 6-Size Structure.
 #'
 #' @seealso See \code{\link{psdVal}}, \code{\link{psdPlot}}, \code{\link{psdAdd}}, \code{\link{PSDlit}}, \code{\link{tictactoe}}, \code{\link{lencat}}, and \code{\link{rcumsum}} for related functionality.
 #'
-#' @references Ogle, D.H. 2016. \href{http://derekogle.com/IFAR/}{Introductory Fisheries Analyses with R}Chapman & Hall/CRC, Boca Raton, FL.
+#' @references Ogle, D.H. 2016. \href{https://fishr-core-team.github.io/fishR/pages/books.html#introductory-fisheries-analyses-with-r}{Introductory Fisheries Analyses with R}Chapman & Hall/CRC, Boca Raton, FL.
 #' 
-#' Guy, C.S., R.M. Neumann, and D.W. Willis2006New terminology for proportional stock density (PSD) and relative stock density (RSD): proportional size structure (PSS)Fisheries 31:86-87  [Was (is?) from http://pubstorage.sdstate.edu/wfs/415-F.pdf.]
+#' Guy, C.S., R.M. Neumann, and D.W. Willis. 2006. New terminology for proportional stock density (PSD) and relative stock density (RSD): proportional size structure (PSS). Fisheries 31:86-87. [Was (is?) from http://pubstorage.sdstate.edu/wfs/415-F.pdf.]
 #'
-#' Guy, C.S., R.M. Neumann, D.W. Willis, and R.O. Anderson2006Proportional size distribution (PSD): A further refinement of population size structure index terminologyFisheries 32:348[Was (is?) from http://pubstorage.sdstate.edu/wfs/450-F.pdf.]
+#' Guy, C.S., R.M. Neumann, D.W. Willis, and R.O. Anderson2006Proportional size distribution (PSD): A further refinement of population size structure index terminology. Fisheries. 32:348. [Was (is?) from http://pubstorage.sdstate.edu/wfs/450-F.pdf.]
 #' 
-#' Neumann, R. M. and Allen, M. S2007Size structure. In Guy, C. S. and Brown, M. L., editors, Analysis and Interpretation of Freshwater Fisheries Data, Chapter 9, pages 375-421. American Fisheries Society, Bethesda, MD.
+#' Neumann, R.M. and Allen, M.S. 2007. Size structure. In Guy, C.S. and Brown, M.L., editors, Analysis and Interpretation of Freshwater Fisheries Data, Chapter 9, pages 375-421. American Fisheries Society, Bethesda, MD.
 #'
-#' Willis, D.W., B.R. Murphy, and C.S. Guy1993Stock density indices: development, use, and limitationsReviews in Fisheries Science 1:203-222[Was (is?) from http://web1.cnre.vt.edu/murphybr/web/Readings/Willis\%20et\%20al.pdf.]
+#' Willis, D.W., B.R. Murphy, and C.S. Guy. 1993. Stock density indices: development, use, and limitations. Reviews in Fisheries Science 1:203-222. [Was (is?) from http://web1.cnre.vt.edu/murphybr/web/Readings/Willis\%20et\%20al.pdf.]
 #'
 #' @keywords hplot
 #'
@@ -46,8 +47,8 @@
 #' ## Random length data
 #' # suppose this is yellow perch to the nearest mm
 #' yepdf <- data.frame(yepmm=round(c(rnorm(100,mean=125,sd=15),
-#'                       rnorm(50,mean=200,sd=25),
-#'                       rnorm(20,mean=300,sd=40)),0),
+#'                                   rnorm(50,mean=200,sd=25),
+#'                                   rnorm(20,mean=300,sd=40)),0),
 #'                     species=rep("Yellow Perch",170))
 #' psdCalc(~yepmm,data=yepdf,species="Yellow perch",digits=1)
 #' psdCalc(~yepmm,data=yepdf,species="Yellow perch",digits=1,drop0Est=TRUE)
@@ -83,6 +84,12 @@
 #' ## Control the digits
 #' psdCalc(~yepmm,data=yepdf,species="Yellow perch",digits=1)
 #' 
+#' ## Working with a species not in PSDlit ... same data, but don't give species
+#' psdCalc(~yepmm,data=yepdf,addLens=c("stock"=130,"quality"=200,"preferred"=250,
+#'                                     "memorable"=300,"trophy"=380))
+#' psdCalc(~yepmm,data=yepdf,addLens=c("stock"=130,"quality"=200,
+#'                                     "preferred"=250,"name1"=220))
+#'                                     
 #' @export psdCalc
 psdCalc <- function(formula,data,species,units=c("mm","cm","in"),
                     method=c("multinomial","binomial"),conf.level=0.95,
@@ -96,13 +103,35 @@ psdCalc <- function(formula,data,species,units=c("mm","cm","in"),
   ## Check on conf.level
   iCheckConfLevel(conf.level) 
   
-  ## make sure species is not missing
-  if (missing(species)) STOP("Must include a species name in 'species'.")
+  ## make sure species is not missing, or if it is that addLens have been given
+  if (!missing(species)) {
+    brks <- psdVal(species,units=units,incl.zero=FALSE,
+                   addLens=addLens,addNames=addNames)    
+  } else {
+    ## species is missing so must have and addLens
+    if (is.null(addLens)) STOP("Must include name in 'species' or lengths in 'addLens'.")
+    ## ... and addLens must have at least two values
+    if (length(addLens)<2) STOP("'addLens' must contain at least two length categories.")
+    ## ... and those lengths must be named ...
+    if (is.null(names(addLens))) {
+      if (is.null(addNames)) 
+        STOP("Category names must be defined in 'addLens' or given in 'addNames'.")
+      if (length(addLens)!=length(addNames))
+        STOP("'addLens' and 'addNames' are different lengths.")
+      names(addLens) <- addNames
+    }
+    ## first category must be "stock"
+    if (names(addLens)[1]!="stock") STOP("First category name must be 'stock'.")
+    ## another category must be "quality"
+#    if (!("quality" %in% names(addLens)))
+#      STOP("One length category must be called 'quality'")
+    ## looks good so set brks to addLens (but make sure they are ordered)
+    brks <- addLens[order(addLens)]
+  }
+
   ## find psd lengths for this species
-  brks <- psdVal(species,units=units,incl.zero=FALSE,
-                 addLens=addLens,addNames=addNames)
   ## perform checks and initial preparation of the data.frame
-  dftemp <- iPrepData4PSD(formula,data,brks["stock"],units)
+  dftemp <- iPrepData4PSD(formula,data,brks[1],units)
   ## add the length categorization variable, don't drop unused levels
   dftemp <- lencat(formula,data=dftemp,breaks=brks,vname="lcatr",
                    use.names=TRUE,droplevels=FALSE)
@@ -111,7 +140,7 @@ psdCalc <- function(formula,data,species,units=c("mm","cm","in"),
   ## make the proportions table
   ptbl <- prop.table(table(dftemp$lcatr))
   ## check to see if some fish are more than quality-sized
-  if (!cumsum(ptbl)[["quality"]]<1) WARN("No 'quality' or larger fish in sample.")
+  if (!cumsum(ptbl)[[2]]<1) WARN("No fish in larger than 'stock' categories.")
   ## compute all traditional and interval PSD values
   res <- iGetAllPSD(ptbl,n=n,method=method,conf.level=conf.level,digits=digits)
   ## decide to keep intermediate calculation columns or not (in first two columns)
