@@ -64,32 +64,32 @@ test_that("Summarize() results, single quantitative variable",{
   exp <- c(9,9,15,sd(d1$q2),11,13,15,17,19,0)  # all possible results
   names(exp) <- qnms1
   tmp <- Summarize(~q2,data=d1)
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp[-c(2,10)])  # drop nvalid & percZero from expectations
   tmp <- Summarize(~q2,data=d1,nvalid="always")
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp[-c(10)])    # drop percZero from expectations
   tmp <- Summarize(~q2,data=d1,percZero="always")
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp[-c(2)])     # drop nvalid from expectations
   tmp <- Summarize(~q2,data=d1,nvalid="always",percZero="always")
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp)
   
   ## no NAs, but zeros
   exp <- c(9,9,4,sd(d1$q1),0,2,4,6,8,1/9*100)  # all possible results
   names(exp) <- qnms1
   tmp <- Summarize(~q1,data=d1)
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp[-c(2)])     # drop nvalid from expectations
   tmp <- Summarize(~q1,data=d1,percZero="never")
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp[-c(2,10)])  # drop nvalid & percZero from expectations
   tmp <- Summarize(~q1,data=d1,nvalid="always",percZero="never")
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp[-c(10)])    # drop percZero from expectations
   tmp <- Summarize(~q1,data=d1,nvalid="always")
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp)
   
   ## NAs and zeros
@@ -97,16 +97,16 @@ test_that("Summarize() results, single quantitative variable",{
            ,0,1.75,3.5,5.25,7,1/8*100)  # all possible results
   names(exp) <- qnms1
   tmp <- Summarize(~q4,data=d1)
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp)
   tmp <- Summarize(~q4,data=d1,nvalid="never",percZero="never")
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp[-c(2,10)])  # drop nvalid & percZero from expectations
   tmp <- Summarize(~q4,data=d1,percZero="never")
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp[-c(10)])    # drop percZero from expectations
   tmp <- Summarize(~q4,data=d1,nvalid="never")
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp[-c(2)])     # drop nvalid from expectations
 })
 
@@ -118,7 +118,7 @@ test_that("Summarize() results, quantitative variable by single factor",{
                     max=c(13,16,19),percZero=rep(0,3),
                     stringsAsFactors=FALSE)
   tmp <- Summarize(q2~f1,data=d1)
-  expect_is(tmp,"data.frame")
+  expect_equal(class(tmp),"data.frame")
   expect_equal(tmp,exp[,-c(3,11)])
   tmp <- Summarize(q2~f1,data=d1,nvalid="always")
   expect_equal(tmp,exp[,-c(11)])   # drop percZero from expectations
@@ -134,7 +134,7 @@ test_that("Summarize() results, quantitative variable by single factor",{
                     max=c(2,5,8),percZero=c(1,0,0)/3*100,
                     stringsAsFactors=FALSE)
   tmp <- Summarize(q1~f1,data=d1)
-  expect_is(tmp,"data.frame")
+  expect_equal(class(tmp),"data.frame")
   expect_equal(tmp,exp[,-c(3)])    # drop nvalid from expectations
   tmp <- Summarize(q1~f1,data=d1,percZero="never")
   expect_equal(tmp,exp[,-c(3,11)]) # drop nvalid & percZero from expectations
@@ -151,7 +151,7 @@ test_that("Summarize() results, quantitative variable by single factor",{
                     max=c(1,4,7),percZero=c(50,0,0),
                     stringsAsFactors=FALSE)
   tmp <- Summarize(q4~f1,data=d1)
-  expect_is(tmp,"data.frame")
+  expect_equal(class(tmp),"data.frame")
   expect_equal(tmp,exp)
   tmp <- Summarize(q4~f1,data=d1,nvalid="never",percZero="never")
   expect_equal(tmp,exp[,-c(3,11)]) # drop nvalid & percZero from expectations
@@ -167,7 +167,7 @@ test_that("Summarize() results, quantitative variable by single character",{
                     Q1=c(11,14,17)+0.5,median=c(12,15,18),Q3=c(12,15,18)+0.5,
                     max=c(13,16,19),percZero=rep(0,3),stringsAsFactors=FALSE)
   tmp <- Summarize(q2~c1,data=d1)
-  expect_is(tmp,"data.frame")
+  expect_equal(class(tmp),"data.frame")
   expect_equal(tmp,exp[,-c(3,11)])
   tmp <- Summarize(q2~c1,data=d1,nvalid="always")
   expect_equal(tmp,exp[,-c(11)])   # drop percZero from expectations
@@ -185,7 +185,7 @@ test_that("Summarize() results, quantitative variable by two factors",{
                     Q3=11:19,max=11:19,percZero=rep(0,9),
                     stringsAsFactors=FALSE)
   tmp <- Summarize(q2~f2+f1,data=d1)
-  expect_is(tmp,"data.frame")
+  expect_equal(class(tmp),"data.frame")
   expect_equal(tmp,exp[,-c(4,12)])  # drop nvalid & percZero from expectations
   tmp <- Summarize(q2~f2+f1,data=d1,nvalid="always")
   expect_equal(tmp,exp[,-c(12)])  # drop percZero from expectations
@@ -202,7 +202,7 @@ test_that("Summarize() results using exclude=",{
                     max=c(4,7),percZero=rep(0,2),
                     stringsAsFactors=FALSE)
   tmp <- Summarize(q4~f1,data=d1,exclude="A")
-  expect_is(tmp,"data.frame")
+  expect_equal(class(tmp),"data.frame")
   expect_equal(tmp,exp[,-c(3,11)])  # drop nvalid & percZero from expectations
 })
 
@@ -213,7 +213,7 @@ test_that("Summarize() Results from 1-d matrices and data.frames",{
   tmp <- Summarize(d)
   exp <- c(9,9,5,sd(d),1,3,5,7,9,0)
   names(exp) <- qnms1
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp[-c(2,10)])  # drop nvalid and percZero from expectations
   tmp <- Summarize(d,nvalid="always")
   expect_equal(tmp,exp[-c(10)])    # drop percZero from expectations
@@ -223,27 +223,27 @@ test_that("Summarize() Results from 1-d matrices and data.frames",{
   tmp <- Summarize(~V1,data=d)
   exp <- c(9,9,5,sd(d$V1),1,3,5,7,9,0)
   names(exp) <- qnms1
-  expect_is(tmp,"numeric")
+  expect_equal(class(tmp),"numeric")
   expect_equal(tmp,exp[-c(2,10)])  # drop nvalid and percZero from expectations
   tmp <- Summarize(~V1,data=d,percZero="always")
   expect_equal(tmp,exp[-c(2)])     # drop nvalid from expectations
 })
 
 test_that("Summarize() results, assure 'by' variable is the expected mode/type",{
-  expect_is(Summarize(q1~f1,data=d1)$f1,"factor")
-  expect_is(Summarize(q1~c1,data=d1)$c1,"character")
-  expect_is(Summarize(q1~q3,data=d1)$q3,"numeric")
+  expect_equal(class(Summarize(q1~f1,data=d1)$f1),"factor")
+  expect_equal(class(Summarize(q1~c1,data=d1)$c1),"character")
+  expect_equal(class(Summarize(q1~q3,data=d1)$q3),"numeric")
   tmp <- Summarize(q1~f1+f2,data=d1)
-  expect_is(tmp$f1,"factor")
-  expect_is(tmp$f2,"factor")
+  expect_equal(class(tmp$f1),"factor")
+  expect_equal(class(tmp$f2),"factor")
   tmp <- Summarize(q1~c1+f1,data=d1)
-  expect_is(tmp$c1,"character")
-  expect_is(tmp$f1,"factor")
+  expect_equal(class(tmp$c1),"character")
+  expect_equal(class(tmp$f1),"factor")
   tmp <- Summarize(q1~c1+q3,data=d1)
-  expect_is(tmp$c1,"character")
-  expect_is(tmp$q3,"numeric")
+  expect_equal(class(tmp$c1),"character")
+  expect_equal(class(tmp$q3),"numeric")
   tmp <- Summarize(q1~f1+q3,data=d1)
-  expect_is(tmp$f1,"factor")
-  expect_is(tmp$q3,"numeric")
+  expect_equal(class(tmp$f1),"factor")
+  expect_equal(class(tmp$q3),"numeric")
 })
 
